<?php
/**
 * Homepage Settings
 *
 * @package Showme
 */

// Add new panel
$wp_customize->add_panel( 'homepage_panel', array(
  'title'              => esc_html__( 'Homepage Settings', 'showme' ),
  'priority'           => 26,
) );

// Add new section
$wp_customize->add_section( 'homepage_section', array(
  'title'                => esc_html__( 'Homepage Layout', 'showme' ),
  'panel'                => 'homepage_panel',
  'priority'             => 10,
) );

// Sidebar
$wp_customize->add_setting( 'homepage_sidebar', array(
  'default'              => 'right',
  'sanitize_callback'    => 'vs_sanitize_sidebar',
) );
$wp_customize->add_control( 'homepage_sidebar', array(
  'label'                => esc_html__( 'Sidebar', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'radio',
  'choices'              => array(
    'right'              => esc_html__( 'Right Sidebar', 'showme' ),
    'left'               => esc_html__( 'Left Sidebar', 'showme' ),
    'disabled'           => esc_html__( 'No Sidebar', 'showme' ),
  ),
) );

// Post Summary
$wp_customize->add_setting( 'homepage_summary', array(
  'default'              => 'excerpt',
  'sanitize_callback'    => 'vs_sanitize_summary',
) );
$wp_customize->add_control( 'homepage_summary', array(
  'label'                => esc_html__( 'Post Summary', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'radio',
  'choices'              => array(
    'excerpt'            => esc_html__( 'Use Excerpts', 'showme' ),
    'content'            => esc_html__( 'Use Read More Tag', 'showme' ),
  ),
) );

// Excerpt Length (Number Of Words)
$wp_customize->add_setting( 'homepage_excerpt_length', array(
  'default'              => 50,
  'sanitize_callback'    => 'vs_sanitize_number',
) );
$wp_customize->add_control( new vs_customize_number_control( $wp_customize, 'homepage_excerpt_length', array(
  'label'                => esc_html__( 'Excerpt Length (Number of Words)', 'showme' ),
  'section'              => 'homepage_section',
) ) );

// Heading
$wp_customize->add_setting( 'homepage_heading_post_meta', array(
  'sanitize_callback'    => 'esc_html',
) );
$wp_customize->add_control( new vs_customize_control_heading( $wp_customize, 'homepage_heading_post_meta', array(
  'label'                => esc_html__( 'Post Meta', 'showme' ),
  'section'              => 'homepage_section',
) ) );

// Display Author
$wp_customize->add_setting( 'homepage_author', array(
  'default'              => 1,
  'sanitize_callback'    => 'vs_sanitize_checkbox',
) );
$wp_customize->add_control( 'homepage_author', array(
  'label'                => esc_html__( 'Display Author', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'checkbox',
) );

// Display Date
$wp_customize->add_setting( 'homepage_date', array(
  'default'              => 1,
  'sanitize_callback'    => 'vs_sanitize_checkbox',
) );
$wp_customize->add_control( 'homepage_date', array(
  'label'                => esc_html__( 'Display Date', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'checkbox',
) );

// Display Categorys
$wp_customize->add_setting( 'homepage_categorys', array(
  'default'              => 1,
  'sanitize_callback'    => 'vs_sanitize_checkbox',
) );
$wp_customize->add_control( 'homepage_categorys', array(
  'label'                => esc_html__( 'Display Categorys', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'checkbox',
) );

// Display Read More
$wp_customize->add_setting( 'homepage_read_more', array(
  'default'              => 0,
  'sanitize_callback'    => 'vs_sanitize_checkbox',
) );
$wp_customize->add_control( 'homepage_read_more', array(
  'label'                => esc_html__( 'Display Read More', 'showme' ),
  'section'              => 'homepage_section',
  'type'                 => 'checkbox',
) );

// Static Front Page
$static_front_page = $wp_customize->get_section( 'static_front_page' );
$wp_customize->remove_section( 'static_front_page' );
$wp_customize->add_section( 'static_front_page', array(
  'title'                => esc_html__( 'Static Front Page', 'showme' ),
  'description'          => $static_front_page->description,
  'panel'                => 'homepage_panel',
  'active_callback'      => $static_front_page->active_callback,
  'priority'             => 25,
) );
